@@ -6,18 +6,18 @@ use Carp;
 use vars qw($VERSION);
 use base qw(POE::Filter);
 
-$VERSION = '2.0';
+$VERSION = '2.38';
 
 sub _PUT_LITERAL () { 1 }
 
 # Probably some other stuff should go here.
 
-our $g = {
+my $g = {
   space			=> qr/\x20+/o,
   trailing_space	=> qr/\x20*/o,
 };
 
-our $irc_regex = qr/^
+my $irc_regex = qr/^
   (?:
     \x3a                #  : comes before hand
     (\S+)               #  [prefix]
@@ -51,23 +51,20 @@ sub new {
   my $type = shift;
   croak "$type requires an even number of parameters" if @_ % 2;
   my $buffer = { @_ };
+  $buffer->{uc $_} = delete $buffer->{$_} for keys %{ $buffer };
   $buffer->{BUFFER} = [];
-  return bless($buffer, $type);
+  return bless $buffer, $type;
 }
 
 sub debug {
   my $self = shift;
   my $value = shift;
 
-  if ( defined ( $value ) ) {
+  if ( defined $value ) {
 	$self->{DEBUG} = $value;
 	return $self->{DEBUG};
   }
-  if ( $self->{DEBUG} ) {
-	$self->{DEBUG} = 0;
-  } else {
-	$self->{DEBUG} = 1;
-  }
+  $self->{DEBUG} = $value;
 }
 
 sub get {
@@ -75,17 +72,18 @@ sub get {
   my $events = [];
 
   foreach my $raw_line (@$raw_lines) {
-    warn "->$raw_line \n" if ( $self->{DEBUG} );
+    warn "->$raw_line \n" if $self->{DEBUG};
     if ( my($prefix, $command, $middles, $trailing) = $raw_line =~ m/$irc_regex/ ) {
       my $event = { raw_line => $raw_line };
-      $event->{'prefix'} = $prefix if ($prefix);
-      $event->{'command'} = uc($command);
-      $event->{'params'} = [] if ( defined ( $middles ) || defined ( $trailing ) );
-      push @{$event->{'params'}}, (split /$g->{'space'}/, $middles) if ( defined ( $middles ) );
-      push @{$event->{'params'}}, $trailing if ( defined( $trailing ) );
+      $event->{'prefix'} = $prefix if $prefix;
+      $event->{'command'} = uc $command;
+      $event->{'params'} = [] if defined ( $middles ) || defined ( $trailing );
+      push @{$event->{'params'}}, (split /$g->{'space'}/, $middles) if defined $middles;
+      push @{$event->{'params'}}, $trailing if defined $trailing;
       push @$events, $event;
-    } else {
-      warn "Recieved line $raw_line that is not IRC protocol\n";
+    } 
+    else {
+      warn "Received line $raw_line that is not IRC protocol\n";
     }
   }
   return $events;
@@ -101,17 +99,18 @@ sub get_one {
   my $events = [];
 
   if ( my $raw_line = shift ( @{ $self->{BUFFER} } ) ) {
-    warn "->$raw_line \n" if ( $self->{DEBUG} );
+    warn "->$raw_line \n" if $self->{DEBUG};
     if ( my($prefix, $command, $middles, $trailing) = $raw_line =~ m/$irc_regex/ ) {
       my $event = { raw_line => $raw_line };
-      $event->{'prefix'} = $prefix if ($prefix);
-      $event->{'command'} = uc($command);
-      $event->{'params'} = [] if ( defined ( $middles ) || defined ( $trailing ) );
-      push @{$event->{'params'}}, (split /$g->{'space'}/, $middles) if ( defined ( $middles ) );
-      push @{$event->{'params'}}, $trailing if ( defined( $trailing ) );
+      $event->{'prefix'} = $prefix if $prefix;
+      $event->{'command'} = uc $command;
+      $event->{'params'} = [] if defined ( $middles ) || defined ( $trailing );
+      push @{$event->{'params'}}, (split /$g->{'space'}/, $middles) if defined $middles;
+      push @{$event->{'params'}}, $trailing if defined $trailing;
       push @$events, $event;
-    } else {
-      warn "Recieved line $raw_line that is not IRC protocol\n";
+    } 
+    else {
+      warn "Received line $raw_line that is not IRC protocol\n";
     }
   }
   return $events;
@@ -127,10 +126,10 @@ sub put {
 
   foreach my $event (@$events) {
     if (ref $event eq 'HASH') {
-      my $colonify = ( defined $event->{colonify} ? $event->{colonify} : $self->{colonify} );
+      my $colonify = ( defined $event->{colonify} ? $event->{colonify} : $self->{COLONIFY} );
       if ( _PUT_LITERAL || _checkargs($event) ) {
         my $raw_line = '';
-        $raw_line .= (':' . $event->{'prefix'} . ' ') if (exists $event->{'prefix'});
+        $raw_line .= (':' . $event->{'prefix'} . ' ') if exists $event->{'prefix'};
         $raw_line .= $event->{'command'};
 	if ( $event->{'params'} and ref $event->{'params'} eq 'ARRAY' ) {
 		my $params = [ @{ $event->{'params'} } ];
@@ -140,15 +139,17 @@ sub put {
 			$raw_line .= $param . ' ';
 			$param = shift @$params;
 		}
-		$raw_line .= ':' if ( $param =~ m/\x20/ or $colonify );
+		$raw_line .= ':' if $param =~ m/\x20/ or $colonify;
 		$raw_line .= $param;
 	}
         push @$raw_lines, $raw_line;
-        warn "<-$raw_line \n" if ( $self->{DEBUG} );
-      } else {
+        warn "<-$raw_line \n" if $self->{DEBUG};
+      } 
+      else {
         next;
       }
-    } else {
+    } 
+    else {
       warn __PACKAGE__ . " non hashref passed to put(): \"$event\"\n";
       push @$raw_lines, $event if ref $event eq 'SCALAR';
     }
@@ -156,6 +157,13 @@ sub put {
   return $raw_lines;
 }
 
+sub clone {
+  my $self = shift;
+  my $nself = { };
+  $nself->{$_} = $self->{$_} for keys %{ $self };
+  $nself->{BUFFER} = [ ];
+  return bless $nself, ref $self;
+}
 
 # This thing is far from correct, dont use it.
 sub _checkargs {
@@ -180,13 +188,13 @@ __END__
 
 =head1 NAME
 
-POE::Filter::IRCD -- A POE-based parser for the IRC protocol.
+POE::Filter::IRCD - A POE-based parser for the IRC protocol.
 
 =head1 SYNOPSIS
 
     use POE::Filter::IRCD;
 
-    my $filter = POE::Filter::IRCD->new( DEBUG => 1, colonify => 0 );
+    my $filter = POE::Filter::IRCD->new( debug => 1, colonify => 0 );
     my $arrayref = $filter->get( [ $hashref ] );
     my $arrayref2 = $filter->put( $arrayref );
 
@@ -199,7 +207,8 @@ POE::Filter::IRCD -- A POE-based parser for the IRC protocol.
 =head1 DESCRIPTION
 
 POE::Filter::IRCD provides a convenient way of parsing and creating IRC protocol
-lines. 
+lines. It provides the parsing engine for L<POE::Component::Server::IRC> and L<POE::Component::IRC>.
+A standalone version exists as L<Parse::IRC>.
 
 =head1 CONSTRUCTOR
 
@@ -207,9 +216,11 @@ lines.
 
 =item new
 
-Creates a new POE::Filter::IRCD object. Takes two optional arguments: DEBUG which will print 
-all lines received to STDERR; 'colonify', set to 1 to force the filter to always colonify the
-last param passed in a put(), default is 0. See below for more detail.
+Creates a new POE::Filter::IRCD object. Takes two optional arguments: 
+
+  'debug', which will print all lines received to STDERR;
+  'colonify', set to 1 to force the filter to always colonify the last param passed in a put(),
+              default is 0. See below for more detail.
 
 =back
 
@@ -259,6 +270,10 @@ eg.
 
   $filter->put( [ $hashref ] );
 
+=item clone
+
+Makes a copy of the filter, and clears the copy's buffer.
+
 =item debug
 
 With a true or false argument, enables or disables debug output respectively. Without an argument the behaviour is to toggle the debug status.
@@ -273,6 +288,12 @@ Chris Williams <chris@bingosnet.co.uk>
 
 Jonathan Steinert
 
+=head1 LICENSE
+
+Copyright C<(c)> Chris Williams and Jonathan Steinert
+
+This module may be used, modified, and distributed under the same terms as Perl itself. Please see the license that came with your Perl distribution for details.
+
 =head1 SEE ALSO
 
 L<POE>
@@ -281,5 +302,11 @@ L<POE::Filter>
 
 L<POE::Filter::Stackable>
 
+L<POE::Component::Server::IRC>
+
+L<POE::Component::IRC>
+
+L<Parse::IRC>
+
 =cut
 
